@@ -18,12 +18,6 @@
  */
 ?>
 <?php
-  // If editing or viewing submissions, display the navigation at the top.
-  if (isset($form['submission_info']) || isset($form['navigation'])) {
-    print drupal_render($form['navigation']);
-    print drupal_render($form['submission_info']);
-  }
-
   // Print out the main part of the form.
   // Feel free to break this up and move the pieces within the array.
   print drupal_render($form['submitted']);
@@ -31,9 +25,3 @@
   // Always print out the entire $form. This renders the remaining pieces of the
   // form that haven't yet been rendered above.
   print drupal_render($form);
-
-  // Print out the navigation again at the bottom.
-  if (isset($form['submission_info']) || isset($form['navigation'])) {
-    unset($form['navigation']['#printed']);
-    print drupal_render($form['navigation']);
-  }
